<?php
/*
 * Fait un ping des adresse spécifiées dans le tableau servers et allume en rouge ou vert la diode correspondante
 * Licence : CC -by -nc -sa
 * Matériel associé : shift register 74HC595 8bits, 
 * Auteur : Valentin CARRUESCO  aka idleman (idleman@idleman.fr - http://blog.idleman.fr)
 */


/*
Ce tableau vas contenir toutes les adresses à vérifier
Le chiffre de gauche correspond à la diode liée, et l'inscription de droit à l'ip à surveiller

- L'ip peut être une ip réseau (type 192.168.x.x), une ip web (xxx.xxx.xxx.xxx), ou une URL (http://www.domaine.tld)
- La diode 1 devras avoir sa patte rouge reliée au 1 du shift regster et sa patte verte au 2, la diode 2 sa patte rouge reliée au 3 et sa patte verte au 4 etc...

*/
$servers = array(
1=>'192.168.0.14', 
2=>'192.168.0.10', 
3=>'192.168.0.74', 
4=>'192.168.0.27', 
5=>'192.168.0.27', 
6=>'192.168.0.1', 
7=>'blog.idleman.fr', 
8=>'www.google.fr', 
);


//Définis le numéro wiring PI du GPIO du raspberry PI qui est branché à la patte SER du shift register
DEFINE('SER_Pin',7);
//Définis le numéro wiring PI du GPIO du raspberry PI qui est branché à la patte RCLK du shift register
DEFINE('RCLK_Pin',6);
//Définis le numéro wiring PI du GPIO du raspberry PI qui est branché à la patte SRCLK du shift register
DEFINE('SRCLK_Pin',5);
//Définis le que le mot clé LOW sera équivalent à 0 (utilisé pour mettre les GPIO à 0 ou 1)
DEFINE('LOW',0);
//Définis le que le mot clé HIGH sera équivalent à 1 (utilisé pour mettre les GPIO à 0 ou 1)
DEFINE('HIGH',1);
//Définis le que le mot clé OUTPUT sera équivalent à out (utilisé pour régler le mode des GPIO en sortie/entrée)
DEFINE('OUTPUT','out');
//Définis le que le mot clé INPUT sera équivalent à in (utilisé pour régler le mode des GPIO en sortie/entrée)
DEFINE('INPUT','in');
//Définis le nombre total de PIN des hsift register utilisés (2 shift à 8 pin soit 16 pins)
DEFINE('numOfRegisterPins',16);



//Tableau qui vas contenir les pin register que nous souhaitons mettre à 0 ou 1
$GLOBALS['registers'] = array();

//On met les 3 GPIO du RPI en sortie
pinMode(SER_Pin, OUTPUT);
pinMode(RCLK_Pin, OUTPUT);
pinMode(SRCLK_Pin, OUTPUT);


//Configure un pin GPIO (rien n'est mis à jour tant que writeRegisters n'est pas appelé)
function write($pin, $state){
	$GLOBALS['registers'][$pin] = $state;
	writeRegisters();
}

//remet tout les pin à 0
function clearRegisters(){
  for($i = numOfRegisterPins - 1; $i >=  0; $i--){
     $GLOBALS['registers'][$i] = LOW;
  }
  writeRegisters();
} 
 
//Envois tout les pins configurés au shift register 
function writeRegisters(){
  digitalWrite(RCLK_Pin, LOW);
  for($i = numOfRegisterPins - 1; $i >=  0; $i--){
    digitalWrite(SRCLK_Pin, LOW);
    $val = $GLOBALS['registers'][$i];
    digitalWrite(SER_Pin, $val);
    digitalWrite(SRCLK_Pin, HIGH);
  }
  digitalWrite(RCLK_Pin, HIGH);
}

//Fonction de base pour définir le mode d'un pin GPIO (entree/sortie) sur le rapsberry PI
function pinMode($pin, $mode){
	command('/usr/local/bin/gpio mode '.$pin.' '.$mode);
}

//Fonction de base pour ouvrir/fermer un pin GPIO sur le rapsberry PI
function digitalWrite($pin, $state){
	command('/usr/local/bin/gpio write '.$pin.' '.$state);
}






$result = array();

foreach($servers as $led=>$ip){
	if(exec('ping '.$ip.' -w 1')){
		$result[$led] = true;
		echo $servers[$led].' : OK'."\n";
	}else{
		$result[$led] = false;
		echo $servers[$led].' : KO'."\n";
	}
}
clearRegisters();
foreach($servers as $led=>$ip){
	if($result[$led]){
		green($led);
	}else{
		red($led);
	}
	
}



function green($pin){
	on(($pin*2) -1);
}
function red($pin){
	on(($pin*2)-2);
}



function on($pin){
	write($pin, HIGH);
}
function off($pin){
	write($pin, LOW);
}

function command($command){
	system($command);
}


?>